
// (c) COPYRIGHT URI/MIT 1997-98
// Please read the full copyright statement in the file COPYRIGHT.  
//
// Authors: reza (Reza Nekovei)

// This is the main CGI program which extracts DAS class attributes from a
// FreeFrom data file. In addition, the attributes from an external file (if 
// exist, with the same name as the FreeFrom file and extension of .das at the 
// end) are extracted and added to the in-memory atrribute table before it is 
// sent over the network to the client side. 
//
// ReZa 6/28/97

#include "config_ff.h"

static char rcsid[] not_used = {"$Id: ff_das.cc,v 1.10.4.1 2001/05/23 18:14:53 jimg Exp $"};

#include <iostream>
#include <string>

#include "DAS.h"
#include "cgi_util.h"
#include "DODSFilter.h"

// These must be defined here to resolve symbols declared as extern in
// FFByte.cc, ... 8/12/98 jhrg

long BufPtr = 0; // cache pointer
long BufSiz =0; // Cache size
char *BufVal = NULL; // cache buffer

extern void get_attributes(DAS &das, string filename) throw(Error);

int 
main(int argc, char * argv[])
{
    DAS das;
    DODSFilter df(argc, argv);

    try {
	if (!df.OK()) {
	    df.print_usage();
	    return 1;
	}

	if (df.version()) {
	    df.send_version_info();
	    return 0;
	}

	get_attributes(das, df.get_dataset_name());

	df.read_ancillary_das(das);

	df.send_das(das);
    }
    catch (Error &e) {
      // At this level, send any error message both to the system log and to
      // the client. Return an error condition to the shell.
      ErrMsgT(e.get_error_message());
      set_mime_text(cout, dods_error, df.get_cgi_version());
      e.print(cout);
      return 1;
    }

    return 0;
}

// $Log: ff_das.cc,v $
// Revision 1.10.4.1  2001/05/23 18:14:53  jimg
// Merged with changes on the release-3-1 branch. This apparently was not
// done corrrectly the first time around.
//
// Revision 1.10  2000/10/12 18:11:45  jimg
// Added more exception stuff. Reworked the get/read_description() functions
// so they throw Error and InternalErr instead of returning codes.
//
// Revision 1.9  2000/10/11 19:37:56  jimg
// Moved the CVS log entries to the end of files.
// Changed the definition of the read method to match the dap library.
// Added exception handling.
// Added exceptions to the read methods.
//
// Revision 1.8  1999/05/27 17:02:23  jimg
// Merge with alpha-3-0-0
//
// Revision 1.7.2.1  1999/05/20 21:43:06  edavis
// Fix spelling of COPYRIGHT and remove some #if 0 stuff.
//
// Revision 1.7  1999/05/05 01:48:00  jimg
// The catch block now correctly generates a MIME header for Error objects sent
// back to the client.
//
// Revision 1.6  1999/05/04 02:55:37  jimg
// Merge with no-gnu
//
// Revision 1.5.12.1  1999/05/01 04:40:29  brent
// converted old String.h to the new std C++ <string> code
//
// Revision 1.5  1998/08/12 21:21:09  jimg
// Massive changes from Reza. Compatible with the new FFND library
//
// Revision 1.4  1998/04/21 17:14:07  jimg
// Fixes for warnings, etc
//
// Revision 1.3  1998/04/16 18:11:23  jimg
// Sequence support added by Reza
